X-Git-Url: https://git.saurik.com/wxWidgets.git/blobdiff_plain/c3952f6524b5827420836f856ef2074f20e72849..c74b07ac26d4e7624ec7a7115bbade0cf3336c13:/include/wx/html/htmltag.h
diff --git a/include/wx/html/htmltag.h b/include/wx/html/htmltag.h
index e0370b6b12..3853333866 100644
--- a/include/wx/html/htmltag.h
+++ b/include/wx/html/htmltag.h
@@ -4,43 +4,50 @@
// Author: Vaclav Slavik
// RCS-ID: $Id$
// Copyright: (c) 1999 Vaclav Slavik
-// Licence: wxWindows Licence
+// Licence: wxWindows licence
/////////////////////////////////////////////////////////////////////////////
-
#ifndef _WX_HTMLTAG_H_
#define _WX_HTMLTAG_H_
-#ifdef __GNUG__
-#pragma interface "htmltag.h"
-#endif
-
#include "wx/defs.h"
+
#if wxUSE_HTML
+#include "wx/object.h"
+#include "wx/arrstr.h"
+
+class WXDLLIMPEXP_FWD_CORE wxColour;
+class WXDLLIMPEXP_FWD_HTML wxHtmlEntitiesParser;
+
//-----------------------------------------------------------------------------
// wxHtmlTagsCache
// - internal wxHTML class, do not use!
//-----------------------------------------------------------------------------
-struct wxHtmlCacheItem;
+class wxHtmlTagsCacheData;
-class WXDLLEXPORT wxHtmlTagsCache : public wxObject
+class WXDLLIMPEXP_HTML wxHtmlTagsCache
{
- DECLARE_DYNAMIC_CLASS(wxHtmlTagsCache)
-
private:
- wxHtmlCacheItem *m_Cache;
- int m_CacheSize;
+ wxHtmlTagsCacheData *m_Cache;
int m_CachePos;
+ wxHtmlTagsCacheData& Cache() { return *m_Cache; }
+
public:
- wxHtmlTagsCache() : wxObject() {m_CacheSize = 0; m_Cache = NULL;}
+ wxHtmlTagsCache() {m_Cache = NULL;}
wxHtmlTagsCache(const wxString& source);
- ~wxHtmlTagsCache() {free(m_Cache);}
+ virtual ~wxHtmlTagsCache();
// Finds parameters for tag starting at at and fills the variables
- void QueryTag(int at, int* end1, int* end2);
+ void QueryTag(const wxString::const_iterator& at,
+ const wxString::const_iterator& inputEnd,
+ wxString::const_iterator *end1,
+ wxString::const_iterator *end2,
+ bool *hasEnding);
+
+ DECLARE_NO_COPY_CLASS(wxHtmlTagsCache)
};
@@ -50,73 +57,117 @@ public:
// by wxHtmlParser.
//--------------------------------------------------------------------------------
-class WXDLLEXPORT wxHtmlTag : public wxObject
+class WXDLLIMPEXP_HTML wxHtmlTag
{
- DECLARE_CLASS(wxHtmlTag)
-
-public:
+protected:
// constructs wxHtmlTag object based on HTML tag.
// The tag begins (with '<' character) at position pos in source
// end_pos is position where parsing ends (usually end of document)
- wxHtmlTag(const wxString& source, int pos, int end_pos, wxHtmlTagsCache* cache);
+ wxHtmlTag(wxHtmlTag *parent,
+ const wxString *source,
+ const wxString::const_iterator& pos,
+ const wxString::const_iterator& end_pos,
+ wxHtmlTagsCache *cache,
+ wxHtmlEntitiesParser *entParser);
+ friend class wxHtmlParser;
+public:
+ ~wxHtmlTag();
+
+ wxHtmlTag *GetParent() const {return m_Parent;}
+ wxHtmlTag *GetFirstSibling() const;
+ wxHtmlTag *GetLastSibling() const;
+ wxHtmlTag *GetChildren() const { return m_FirstChild; }
+ wxHtmlTag *GetPreviousSibling() const { return m_Prev; }
+ wxHtmlTag *GetNextSibling() const {return m_Next; }
+ // Return next tag, as if tree had been flattened
+ wxHtmlTag *GetNextTag() const;
// Returns tag's name in uppercase.
inline wxString GetName() const {return m_Name;}
- // Returns TRUE if the tag has given parameter. Parameter
+ // Returns true if the tag has given parameter. Parameter
// should always be in uppercase.
- // Example : HasParam("SRC") returns TRUE
+ // Example :
HasParam("SRC") returns true
bool HasParam(const wxString& par) const;
// Returns value of the param. Value is in uppercase unless it is
// enclosed with "
// Example :
GetParam("ALIGN") returns (RIGHT) //
GetParam("SRC") returns (WhaT.jpg)
- // (or ("WhaT.jpg") if with_commas == TRUE)
- wxString GetParam(const wxString& par, bool with_commas = FALSE) const;
+ // (or ("WhaT.jpg") if with_quotes == true)
+ wxString GetParam(const wxString& par, bool with_quotes = false) const;
+
+ // Convenience functions:
+ bool GetParamAsColour(const wxString& par, wxColour *clr) const;
+ bool GetParamAsInt(const wxString& par, int *clr) const;
- // Scans param like scanf() functions family do.
+ // Scans param like scanf() functions family does.
// Example : ScanParam("COLOR", "\"#%X\"", &clr);
- // This is always with with_commas=FALSE
+ // This is always with with_quotes=false
// Returns number of scanned values
// (like sscanf() does)
// NOTE: unlike scanf family, this function only accepts
// *one* parameter !
- int ScanParam(const wxString& par, wxChar *format, void *param) const;
+ int ScanParam(const wxString& par, const char *format, void *param) const;
+ int ScanParam(const wxString& par, const wchar_t *format, void *param) const;
// Returns string containing all params.
- inline const wxString& GetAllParams() const {return m_Params;}
+ wxString GetAllParams() const;
- // return TRUE if this is ending tag () or FALSE
- // if it isn't (